@@ -3,10 +3,10 @@
 <div id="footer">
 <!-- If you'd like to support WordPress, having the "powered by" link someone on your blog is the best way, it's our only promotion or advertising. -->
 	<p>
-		<?php bloginfo('name'); ?> is proudly powered by 
+		<?php bloginfo('name'); ?> is proudly powered by
 		<a href="http://wordpress.org/">WordPress</a>
-		<br /><a href="feed:<?php bloginfo('rss2_url'); ?>">Entries (RSS)</a>
-		and <a href="feed:<?php bloginfo('comments_rss2_url'); ?>">Comments (RSS)</a>.
+		<br /><a href="<?php bloginfo('rss2_url'); ?>">Entries (RSS)</a>
+		and <a href="<?php bloginfo('comments_rss2_url'); ?>">Comments (RSS)</a>.
 		<!-- <?php echo get_num_queries(); ?> queries. <?php timer_stop(1); ?> seconds. -->
 	</p>
 </div>
